pub struct RTreeEntry {
pub id: EntryId,
pub bbox: BoundingBox,
}Expand description
A spatial entry stored in an R-tree leaf.
Fields
id: EntryIdbbox: BoundingBoxTrait Implementations
Sourceimpl Archive for RTreeEntry
impl Archive for RTreeEntry
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRTreeEntry
type Archived = ArchivedRTreeEntry
The archived representation of this type. Read more
Sourcetype Resolver = RTreeEntryResolver
type Resolver = RTreeEntryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for RTreeEntry
impl Clone for RTreeEntry
Sourcefn clone(&self) -> RTreeEntry
fn clone(&self) -> RTreeEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RTreeEntry
impl Debug for RTreeEntry
Sourceimpl<'de> Deserialize<'de> for RTreeEntry
impl<'de> Deserialize<'de> for RTreeEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RTreeEntry, __D> for Archived<RTreeEntry>where
EntryId: Archive,
<EntryId as Archive>::Archived: Deserialize<EntryId, __D>,
BoundingBox: Archive,
<BoundingBox as Archive>::Archived: Deserialize<BoundingBox, __D>,
impl<__D: Fallible + ?Sized> Deserialize<RTreeEntry, __D> for Archived<RTreeEntry>where
EntryId: Archive,
<EntryId as Archive>::Archived: Deserialize<EntryId, __D>,
BoundingBox: Archive,
<BoundingBox as Archive>::Archived: Deserialize<BoundingBox, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RTreeEntry, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RTreeEntry, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<'__msgpack_de> FromMessagePack<'__msgpack_de> for RTreeEntry
impl<'__msgpack_de> FromMessagePack<'__msgpack_de> for RTreeEntry
Sourceimpl Serialize for RTreeEntry
impl Serialize for RTreeEntry